<?php
/**
 * @file
 * Administration pages for the 'Create content' module.
 */

/**
 * Form builder; Administration page for the 'Create content' module.
 *
 * @ingroup forms
 */
function create_content_admin_settings() {
  module_load_include('inc', 'create_content');

  create_content_load_all_includes();

  $modules = module_implements('create_content');
  asort($modules);
  foreach ($modules as $module) {
    $module_info = unserialize(db_result(db_query("SELECT info FROM {system} WHERE name='%s'", $module)));
    $module_name = $module_info['name'];

    $form[$module] = array(
      '#type' => 'fieldset',
      '#title' => $module_name,
      '#collapsible' => TRUE,
    );

    // Enable/disable create context for a module.
    $form[$module]['create_content_'. $module .'_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable create content handler for %module_name module', array('%module_name' => $module_name )),
      '#default_value' => variable_get('create_content_'. $module .'_enabled', '0'),
      '#required' => TRUE,
    );

    // Select allowed types.
    $create_content_allowed_types_func = $module .'_create_content_allowed_types';
    if (function_exists($create_content_allowed_types_func )) {
      $form[$module]['create_content_'. $module .'_allowed_types'] = array(
        '#type' => 'checkboxes',
        '#title' => t('Select create content types for %module_name module', array('%module_name' => $module_name )),
        '#description' => t('Leave unchecked to select all types.'),
        '#default_value' => variable_get('create_content_'. $module .'_allowed_types', array()),
        '#options' => $create_content_allowed_types_func(),
      );
    }

    // Select fields.
    $create_content_field_func = $module .'_create_content_fields';
    if (function_exists($create_content_field_func)) {
      $form[$module]['create_content_'. $module .'_fields'] = array(
        '#type' => 'checkboxes',
        '#title' => t('Select create content fields for %module_name module', array('%module_name' => $module_name )),
        '#description' => t('Leave unchecked to select all fields.'),
        '#default_value' => variable_get('create_content_'. $module .'_fields', array()),
        '#options' => $create_content_field_func(),
      );
    }
  }
  $form['#submit'][] = 'create_content_admin_settings_submit';
  return system_settings_form($form);
}

/**
 * Process create_content_admin_settings() submissions.
 *
 * @ingroup forms
 */
function create_content_admin_settings_submit($form, &$form_state) {
  // Cleanup 'create_content_{module}_fields' value array so that only
  // checked values are saved in a variable.
  foreach ($form_state['values'] as $name => &$value) {
    // Cleanup allowed types
    if ( preg_match('/^create_content_.*_(allowed_types|fields)$/', $name) ) {
      foreach ($value as $name => $checked) {
        if ($checked === 0) {
          unset($value[$name]);
        }
      }
    }
  }
}
