/**
 * @file
 * Add toggle suggested links to create content (node/add) lists.
 *
 * Notes:
 * - The toggle is designed to syncronize the state of all create content
 *   (node/add) lists on the page.
 */

(function ($) {

Drupal.createContent = {}

Drupal.createContent.menuSelectors = [
  '.node-type-list',
  'a:contains(Create content) ~ ul',
  'ul.create-content-list',
  '#block-admin-create ul.menu' // Admin.module
];

Drupal.createContent.init = function() {
  // Add and track classes for create-content links
  var found_suggested = false;
  var found_default = false;

  $('a[href^=' + Drupal.settings.basePath + 'node/add]').each(function() {
    if (this.className) {
      return;
    }
    else if (this.href.match(/node\/add(\?|$)/) ) {
      this.className = 'create-content-link';
    }
    else if (this.href.indexOf('?create_content=1') != -1) {
      this.className = 'create-content-link create-content-link-suggested';
      found_suggested = true;
    }
    else if (this.href.indexOf('?') != -1) {
      // Treat node/add links not generated by create_content.module as suggested links with custom class.
      this.className = 'create-content-link create-content-link-custom';
      found_suggested = true;
    }
    else {
      this.className = 'create-content-link-default';
      found_default = true;
    }
  });

  // Skip if there are no default and suggested links.
  if (!found_suggested || !found_default) {
    return;
  }

  // Find list the create content 'node/add' links.
  $( Drupal.createContent.menuSelectors.join(', ') ).each(function() {
    // Add toggle to list.
    var tag = (this.tagName == 'DL') ? 'p' : 'li';
    $(this).prepend('<' + tag + ' class="create-content-toggle">' +
      '<a href="#">[Show all]</a>' +
      '</' + tag + '>');
  });

  // Hide default links and init toggle.

  // Note: The main create content page (node/add) use theme_node_add_list which generates
  // a <dl> which the new seven.theme used a <ul> so that below accounts for both formats.

  if ( $('.create-content-toggle') ) {

    // Use style="display:none" to insure hide/show is properly initialized to hidden menus.
    var $items = $('.create-content-link-default').parent();

    $items.attr('style', 'display:none');

    // Use dd to default node add list.
    $items.next('dd').attr('style', 'display:none');
    // Use li to custom node add list. (including seven.theme)
    $items.parent('li').attr('style', 'display:none');

    $('.create-content-toggle a').click(  function() {
      var $items = $('.create-content-link-default').parent();

      if ( $(this).html() == '[Show all]'  ) {

        // title
        $items.attr('style', 'display:block');

        // description
        $items.next('dd').attr('style', 'display:block');
        $items.parent('li').attr('style', 'display:block');

        $('.create-content-toggle a').html('[Show suggested]');
        $('#create-content-title').hide();

      }
      else {

        // title
        $items.attr('style', 'display:none');

        // description
        $items.next('dd').attr('style', 'display:none');
        $items.parent('li').attr('style', 'display:none');

        $('.create-content-toggle a').html('[Show all]');
        $('#create-content-title').show();

      }

      return false;
    });
  }
}

$(Drupal.createContent.init);

})(jQuery)
