<?php
/**
 * @file
 * Create content hook and functions for the content_taxonomy.module.
 */


/**
 * Implementation of hook_create_content() on behalf of the content_taxonomy.module.
 */
function content_taxonomy_create_content() {
  // Load taxonomy info and make sure there is term (tid).
  list($vid, $tid) = taxonomy_create_content_get_info();
  if (!$tid) {
    return;
  }

  $contexts = content_taxonomy_create_content_load_contexts();
  $context = array();
  if ($field = $contexts[$vid]) {
    foreach ($field as $field_name => $allowed_types) {
      $context[$field_name] = array(
        'allowed_types' => $allowed_types,
      );
    }
  }

  // DEBUG:
  // dsm($context);

  return $context;
}

/**
 * Implementation of hook_create_content_fields().
 */
function content_taxonomy_create_content_fields() {
  return create_content_get_fields('content_taxonomy');
}


////////////////////////////////////////////////////////////////////////////////
// Utility functions
////////////////////////////////////////////////////////////////////////////////

/**
 * Load and cache all content taxonomy contexts.
 */
function content_taxonomy_create_content_load_contexts() {
  $fields = variable_get('create_content_content_taxonomy_fields', array());

  list($vid, $tid) = taxonomy_create_content_get_info();

  $contexts = array();
  $result = db_query("SELECT field_name, multiple, type, global_settings FROM {content_node_field} WHERE type='content_taxonomy'");
  while ($field_record = db_fetch_array($result)) {
    if ($fields && !$fields[ $field_record['field_name'] ]) {
      continue;
    }

    $settings = unserialize($field_record['global_settings']);
    $vocabulary = taxonomy_vocabulary_load($settings['vid']);

    $allowed_types = array();
    content_create_content_get_field_instance_allowed_types($allowed_types, $field_record, $tid, $vocabulary->nodes);

    $contexts[ $vocabulary->vid ][ $field_record['field_name'] ] = $allowed_types;
  }
  return $contexts;
}
