<?php
/**
 * @file
 * Create content hook and functions for the example.module.
 */

 /**
 * Implementation of hook_create_content().
 */
function example_create_content() {
  // Current page's is usually used to create content context.
  $node = create_content_node_load();
  if (!$node) {
    return;
  }

  // Current page's view can also be used to create content context.
  // See view.create_content.inc for an example.

  $context = array();
  $allowed_types = array('topic');
  $context['example'] = array(
    // Query to be appended to all matched types.
    'query' => 'example_default_param=example_default_value&mlid='. $node->book['mlid'],

    // Simply lookup list for matched types.
    'allowed_types' => array_combine($allowed_types, $allowed_types),

    // - or -

    // More complex lookup list for matched types with custom query parameters.
    'allowed_types' => array(
      // Query to be appended to only this matched type.
      'page' => 'example_param=example_value',
    ),
  );
  return $context;
}

/**
 * Implementation of hook_create_content_fields().
 *
 * Used to define which fields should be used when a module is adding create content context.
 *
 * For a usage example see content_taxonomy.create_content.inc.
 */
function example_create_content_fields() {
  return create_content_get_fields('field_type');
}

/**
 * Implementation of hook_create_content_allowed_types().
 *
 * Used to define which content types should be used when a module is adding create content context.
 *
 * For a usage example see menu.create_content.inc.
 */
function menu_create_content_allowed_types() {
  return node_get_types('names');
}

/**
 * Implementation of hook_create_content_node_form_alter().
 *
 * For a usage example see menu.create_content.inc.
 */
function example_create_content_node_form_alter(&$form, &$form_state, $form_id) {
  // Alter $form.

  // Add submit handler.
  $form['#submit'] = array_merge( array('example_create_content_node_form_submit'), $form['#submit']);
}


/**
 * Submission handler; Does something with altered node form..
 *
 * For a usage example see menu.create_content.inc.
 */
function example_create_content_node_form_submit($form, &$form_state) {
  // Handle form submission.
}
