<?php
/**
 * @file
 * Create content hook and functions for the menu.module.
 */


/**
 * Implementation of hook_create_content() on behalf of the menu.module.
 */
function menu_create_content() {
  $node = create_content_node_load();
  // Books are alway prioritized before menus.
  if (!$node || isset($node->book) ) {
    return;
  }

  $menu_item = db_fetch_array(db_query("SELECT mlid, menu_name FROM {menu_links} WHERE module='menu' AND link_path='%s'", create_content_get_path()));
  if (!$menu_item) {
    return;
  }

  $allowed_types = variable_get('create_content_menu_allowed_types', array());
  if (!$allowed_types) {
    $allowed_types = array_keys(node_get_types('names'));
  }

  $context = array();
  $context['menu'] = array(
    'query' => 'edit[menu][parent]='. $menu_item['menu_name'] . urlencode(':') . $menu_item['mlid'],
    'allowed_types' => array_combine($allowed_types, $allowed_types),
  );
  return $context;
}

/**
 * Implementation of hook_create_content_allowed_types().
 */
function menu_create_content_allowed_types() {
  return node_get_types('names');
}

/**
 * Implementation of hook_create_content_node_form_alter().
 */
function menu_create_content_node_form_alter(&$form, &$form_state, $form_id) {
  if (!isset($form['menu']) || !user_access('administer menu') ) {
    return;
  }

  $type = $form['type']['#value'];
  $allowed_types = variable_get('create_content_menu_allowed_types', array());

  if (!empty($allowed_types) && !in_array($type, $allowed_types)) {
    unset($form['menu']);
  }
  else {
    // Add nice little menu title sync widget.
    drupal_add_js( drupal_get_path('module', 'create_content') .'/js/menu.create_content.js');
    $form['menu']['create_content_menu_auto'] = array(
      '#type' => 'checkbox',
      '#weight' => -50,
      '#title' => t("Syncronize menu link title with node title."),
      '#default_value' => 0,
    );

    if (isset($_GET['edit']['menu']['parent'])) {
      $form['menu']['parent']['#default_value'] = $_GET['edit']['menu']['parent'];
      $form['menu']['create_content_menu_auto']['#default_value'] = 1;
    }

    $form['#submit'] = array_merge( array('menu_create_content_node_form_submit'), $form['#submit']);
  }
}

/**
 * Submission handler; Sync node title with link title if javascript is disabled.
 */
function menu_create_content_node_form_submit($form, &$form_state) {
  // Automatically  set menu link title to the node's title.
  if ($form_state['value']['create_content_menu_auto'] == '1' && !$form_state['values']['menu']['link_title']) {
    $form_state['values']['menu']['link_title'] = $form_state['title'];
  }
}
