<?php
/**
 * @file
 * Create content hook and functions for the nodereference.module.
 */


/**
 * Implementation of hook_create_content() on behalf of the nodereference.module.
 */
function nodereference_create_content() {
  $node = create_content_node_load();
  if (!$node) {
    return;
  }

  $contexts = nodereference_create_content_load_contexts($node);

  $context = array();
  if (!empty($contexts[$node->type])) {
    $field = $contexts[$node->type];
    foreach ($field as $field_name => $allowed_types) {
      $context[$field_name] = array(
        'allowed_types' => $allowed_types,
      );
    }
  }

  // DEBUG:
  // dsm($contexts);

  return $context;
}

/**
 * Implementation of hook_create_content_fields().
 */
function nodereference_create_content_fields() {
  return create_content_get_fields('nodereference');
}


////////////////////////////////////////////////////////////////////////////////
// Utility functions
////////////////////////////////////////////////////////////////////////////////

/**
 * Load and cache all nodereference contexts.
 *
 * TODO: Support different types of widgets (include autocomplete, select, radios, etc).
 */
function nodereference_create_content_load_contexts($node) {
  $fields = variable_get('create_content_nodereference_fields', array());

  $contexts = array();
  $result = db_query("SELECT field_name, global_settings, type, multiple FROM {content_node_field} WHERE type='nodereference'");
  while ($field_record = db_fetch_array($result)) {
    $settings = unserialize($field_record['global_settings']);
    if (!$settings['referenceable_types'] ) {
      continue;
    }

    if ($fields && empty($fields[ $field_record['field_name'] ])) {
      continue;
    }

    $allowed_types = array();
    content_create_content_get_field_instance_allowed_types($allowed_types, $field_record, $node->nid);

    $referencable_types = array_filter($settings['referenceable_types']);
    foreach ($referencable_types as $key => $value) {
      $contexts[$key][ $field_record['field_name'] ] = $allowed_types;
    }
  }
  return $contexts;
}
