<?php
/**
 * @file
 * Create content hook and functions for the views.module.
 */


/**
 * Implementation of hook_create_content() on behalf of the create_content.module.
 */
function views_create_content() {
  $context = array();

  if ($page_view = view_create_content_get_page()) {
    // Ideally this should be getting the current page's filter.
    $view = $page_view->default_display->view;
    if ($view->base_table == 'node') {
      // Collect allowed type from filter.
      $context['views'] = array(
        'allowed_types' => view_create_content_get_allowed_types($view),
      );
    }
  }

  // DEBUG
  // dsm($context);

  return $context;
}


////////////////////////////////////////////////////////////////////////////////
// Utility functions.
////////////////////////////////////////////////////////////////////////////////

/**
 * Get current context's views page.
 */
function view_create_content_get_page() {
  if ($page_view = views_get_page_view()) {
    return $page_view;
  }

  $router_item = create_content_menu_get_router_item();
  if ($router_item['page_callback'] == 'views_page') {
    $args = $router_item['page_arguments'] ;
    $name = array_shift($args);
    $display_id = array_shift($args);

    // If display id is an array then just use the first value.
    if (is_array($display_id)) {
      $display_id = $display_id[0];
    }

    $view = views_get_view($name);
    // Load and execute only page views.
    // This prevents views returning XML from throwing 'warning: Cannot modify header information...'
    if ($view && $view->display[$display_id]->display_plugin == 'page') {
      $view->execute_display($display_id, $args);
      return views_get_page_view();
    }
    else {
      return NULL;
    }
  }

  return NULL;
}

/**
 * Get allowed types for selected view.
 */
function view_create_content_get_allowed_types($view) {
  $allowed_types = array();
  view_create_content_set_filters_allowed_types($allowed_types, $view);
  view_create_content_set_arguments_allowed_types($allowed_types, $view);
  return $allowed_types;
}

/**
 * Get allowed types based on a view filters.
 */
function view_create_content_set_filters_allowed_types(&$allowed_types, $view) {
  if (isset($view->display[$view->current_display]->display_options['filters'])) {
    $view_filters = $view->display[$view->current_display]->display_options['filters'];
  }
  else {
    $view_filters = $view->display['default']->display_options['filters'];
  }

  if (!is_array($view_filters)) {
    return array();
  }

  $allowed_types = array();
  foreach ($view_filters as $key => $filter) {
    if (strpos($key, 'type') === 0) {
      if (is_array($filter) && isset($filter['value'])) {
        $allowed_types += $filter['value'];
      }
      elseif (is_object($filter) && isset($filter->value)) {
        $allowed_types += $filter->value;
      }
    }
  }
  return $allowed_types;
}


/**
 * Get allowed types based on a view arguments.
 */
function view_create_content_set_arguments_allowed_types(&$allowed_types, $view) {
  // Get allowed types based on arguments.
  $types = array_keys($allowed_types);
  foreach ($view->argument as $argument) {
    if (!isset($argument->value)) {
      continue;
    }

    if (isset($argument->content_field)) {
      $field = $argument->content_field;
      content_create_content_get_field_instance_allowed_types($allowed_types, $field, $argument->value, $types);
    }
  }
}
